@@ -11,10 +11,6 @@
 #include "crypto_stream_salsa20.h"
 #include "utils.h"
 
-static const unsigned char sigma[16] = {
-    'e', 'x', 'p', 'a', 'n', 'd', ' ', '3', '2', '-', 'b', 'y', 't', 'e', ' ', 'k'
-};
-
 int
 crypto_secretbox_detached(unsigned char *c, unsigned char *mac,
                           const unsigned char *m,
@@ -27,9 +23,12 @@ crypto_secretbox_detached(unsigned char *c, unsigned char *mac,
     unsigned long long                i;
     unsigned long long                mlen0;
 
-    crypto_core_hsalsa20(subkey, n, k, sigma);
+    crypto_core_hsalsa20(subkey, n, k, NULL);
 
-    if (c - m < mlen || c - m > -mlen) {
+    if (((uintptr_t) c >= (uintptr_t) m &&
+         (uintptr_t) c - (uintptr_t) m < mlen) ||
+        ((uintptr_t) m >= (uintptr_t) c &&
+         (uintptr_t) m - (uintptr_t) c < mlen)) {
         memmove(c, m, mlen);
         m = c;
     }
@@ -49,7 +48,9 @@ crypto_secretbox_detached(unsigned char *c, unsigned char *mac,
                       crypto_onetimeauth_poly1305_KEYBYTES ? 1 : -1]);
     crypto_onetimeauth_poly1305_init(&state, block0);
 
-    memcpy(c, block0 + crypto_secretbox_ZEROBYTES, mlen0);
+    for (i = 0U; i < mlen0; i++) {
+        c[i] = block0[crypto_secretbox_ZEROBYTES + i];
+    }
     sodium_memzero(block0, sizeof block0);
     if (mlen > mlen0) {
         crypto_stream_salsa20_xor_ic(c + mlen0, m + mlen0, mlen - mlen0,
@@ -88,14 +89,17 @@ crypto_secretbox_open_detached(unsigned char *m, const unsigned char *c,
     unsigned long long i;
     unsigned long long mlen0;
 
-    crypto_core_hsalsa20(subkey, n, k, sigma);
+    crypto_core_hsalsa20(subkey, n, k, NULL);
     crypto_stream_salsa20(block0, crypto_stream_salsa20_KEYBYTES,
                           n + 16, subkey);
     if (crypto_onetimeauth_poly1305_verify(mac, c, clen, block0) != 0) {
         sodium_memzero(subkey, sizeof subkey);
         return -1;
     }
-    if (m - c < clen || m - c > -clen) {
+    if (((uintptr_t) c >= (uintptr_t) m &&
+         (uintptr_t) c - (uintptr_t) m < clen) ||
+        ((uintptr_t) m >= (uintptr_t) c &&
+         (uintptr_t) m - (uintptr_t) c < clen)) {
         memmove(m, c, clen);
         c = m;
     }
@@ -103,7 +107,9 @@ crypto_secretbox_open_detached(unsigned char *m, const unsigned char *c,
     if (mlen0 > 64U - crypto_secretbox_ZEROBYTES) {
         mlen0 = 64U - crypto_secretbox_ZEROBYTES;
     }
-    memcpy(block0 + crypto_secretbox_ZEROBYTES, c, mlen0);
+    for (i = 0U; i < mlen0; i++) {
+        block0[crypto_secretbox_ZEROBYTES + i] = c[i];
+    }
     crypto_stream_salsa20_xor(block0, block0,
                               crypto_secretbox_ZEROBYTES + mlen0,
                               n + 16, subkey);
